### 0.9.6

```{rubric} Bug fixes
```
* {func}`~rapids_singlecell.tl.louvain` and {func}`~rapids_singlecell.tl.leiden` now works with next version of scanpy  {pr}`127` {smaller}`S Dicks`

```{rubric} Misc
```
* Updates Conda yaml file to work with rapids-24.02 {pr}`128` {smaller}`S Dicks`
